@@ -1,5 +1,3 @@
-/* $Id: shm_limits.c 2422 2005-12-12 09:38:15Z jamesh $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -35,7 +33,7 @@ static const unsigned long _glibtop_sysdeps_shm_limits =
 /* Init function. */
 
 void
-glibtop_init_shm_limits_p (glibtop *server)
+_glibtop_init_shm_limits_p (glibtop *server)
 {
 	int result;
 
